@@ -19,8 +19,12 @@ import gi
 gi.require_version('Gtk', '3.0')
 from gi.repository import Gtk
 
-gi.require_version('AppIndicator3', '0.1')
-from gi.repository import AppIndicator3 as AppIndicator
+try:
+    gi.require_version('AppIndicator3', '0.1')
+    from gi.repository import AppIndicator3 as AppIndicator
+except ValueError:
+    gi.require_version('AyatanaAppIndicator3', '0.1')
+    from gi.repository import AyatanaAppIndicator3 as AppIndicator
 
 from ._util.gtk import GtkIcon, mainloop
 from . import _base
